@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2011 by Lloyd Wood.
+ *  Also Copyright (c) 2013 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -22,7 +22,7 @@
  *
  * Coverage visualization routines.
  *
- * $Id: coverage_vis.c,v 1.117 2011/01/09 20:20:01 lloydwood Exp $
+ * $Id: coverage_vis.c,v 1.120 2013/05/05 05:19:25 lloydwood Exp $
  */
 
 #include <math.h>
@@ -922,7 +922,7 @@ overlay_bitmap(unsigned int h, unsigned int w, unsigned char *b,
 	if (c & mask) {
 	  *(b++) = 1;
 	} else {
-	  b++;
+	  *(b++) = 0;
 	}
 	mask = mask / 2;
       }
