@@ -6,7 +6,7 @@
 #          Robert Thurman.
 #
 #  Copyright (c) 1997 by The Geometry Center.
-#  Also Copyright (c) 2011 by Lloyd Wood.
+#  Also Copyright (c) 2013 by Lloyd Wood.
 #
 #  This file is part of SaVi.  SaVi is free software;
 #  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
 #
 # init.tcl
 #
-# $Id: init.tcl,v 1.77 2011/04/26 20:41:31 lloydwood Exp $
+# $Id: init.tcl,v 1.80 2013/05/05 05:19:26 lloydwood Exp $
 
 proc geomview_init {} {
     global satellites_flag box_sat_flag planes_sat_flag fancy_sat_flag \
@@ -113,7 +113,7 @@ proc app_init {} {
       set modifier "Command"
       set modifier_indicator "Command"
       set PLATFORM 1
-    } elseif {[string equal [tk windowingsystem] win32]} {
+    } elseif {[string equal [tk windowingsystem] win32]||[file exists /cygdrive]} {
       # Tcl on Windows - grey
       set COLOR(bg) #d4d0c8
       set COLOR(abg) #bbb
