@@ -6,7 +6,7 @@
 #          Robert Thurman.
 #
 #  Copyright (c) 1997 by The Geometry Center.
-#  Also Copyright (c) 2011 by Lloyd Wood.
+#  Also Copyright (c) 2013 by Lloyd Wood.
 #
 #  This file is part of SaVi.  SaVi is free software;
 #  you can redistribute it and/or modify it only under
@@ -20,10 +20,10 @@
 #
 # main.tcl
 #
-# $Id: main.tcl,v 1.141 2011/04/26 20:41:31 lloydwood Exp $
+# $Id: main.tcl,v 1.146 2013/05/05 05:37:01 lloydwood Exp $
 
 proc main(build) {} {
-    global main_name COLOR FONT TITLE geomview_module last_filename
+    global main_name COLOR FONT TITLE geomview_module last_filename PLATFORM
 
     if {[eval window(raise) main]} return
 
@@ -105,11 +105,17 @@ proc main(build) {} {
 
     set cmd [build_StdFrame $main_name cmd]
 
+    # needs to be 78 on old 10.4 Mac with supplied Tcl/Tk to avoid crash.
+    set WIDTH 99
+    if {$PLATFORM == 1} {
+        set WIDTH 78
+    }
+
     label $cmd.l -text \
-	"no.  semi-major axis  eccentricity     inclination   long. asc. node  arg. periapsis   time to periapsis   satellite name" \
+	"no.  semi-major axis      eccentricity     inclination   longitude asc. node     arg. periapsis     time to periapsis  satellite name" \
 	-font $FONT(label)
     listbox $cmd.lb -yscrollcommand "$cmd.scroll set" \
-	-height 2 -width 78 -selectmode single \
+	-height 2 -width $WIDTH -selectmode single \
 	-font $FONT(fixed) -bg $COLOR(entry)
     pack $cmd.l -side top -anchor w
     pack $cmd.l -fill none
@@ -117,10 +123,10 @@ proc main(build) {} {
     pack $cmd.lb -fill both -expand 1
     bind $cmd.lb <Button-1> {main(select) [%W nearest %y]}
     bind $cmd.lb <Double-Button-1> {main(dblselect) [%W nearest %y]}
-    bind $cmd.lb <Shift-Button-1> {main(shiftselect) [%W nearest %y]}
-    bind $cmd.lb <Shift-Double-Button-1> {main(shiftdblselect) [%W nearest %y]}
-    bind $cmd.lb <Control-Button-1> {main(controlselect) [%W nearest %y]}
-    bind $cmd.lb <Control-Double-Button-1> {main(controldblselect) [%W nearest %y]}
+    bind $cmd.lb <Shift-Button-1> {main(rangeselect) [%W nearest %y]}
+    bind $cmd.lb <Shift-Double-Button-1> {main(rangedblselect) [%W nearest %y]}
+    bind $cmd.lb <Control-Button-1> {main(itemselect) [%W nearest %y]}
+    bind $cmd.lb <Control-Double-Button-1> {main(itemdblselect) [%W nearest %y]}
     scrollbar $cmd.scroll -command "$cmd.lb yview"
     pack $cmd.scroll -side right -fill y
 
@@ -186,14 +192,14 @@ proc main(constellations_menu) {submenu} {
 	{} \
 	{"Clarke geostationary" "main(constellation) clarke.tcl"} \
 	{"Draim tetrahedral" "main(constellation) draim-4.tcl"} \
-	{"Molnya" "main(constellation) molnya.tcl"} \
-	{"Tundra" "main(constellation) tundra.tcl"} \
+	{"Molnya elliptical" "main(constellation) molnya.tcl"} \
+	{"Tundra elliptical" "main(constellation) tundra.tcl"} \
 	{"Quasi-geostationary" "main(constellation) quasi-geo.tcl"} \
 	{} \
 	{"Globalstar" "main(constellation) globalstar.tcl"} \
 	{"Iridium" "main(constellation) iridium-66.tcl"} \
 	{"Orbcomm" "main(constellation) orbcomm.tcl"} \
-	{"Sirius Radio" "main(constellation) sirius-radio.tcl"} \
+	{"Sirius Radio elliptical" "main(constellation) sirius-radio.tcl"} \
 	{"DMC disaster monitoring" "main(constellation) dmc.tcl"} \
 	{"RapidEye" "main(constellation) rapideye.tcl"} \
 	{} \
@@ -221,7 +227,7 @@ proc main(constellations_menu) {submenu} {
 	{"GS2" "main(constellation) gs2.tcl"} \
 	{"ICO" "main(constellation) ico.tcl"} \
 	{"Macrocell" "main(constellation) macrocell.tcl"} \
-	{"Millimeter" "main(constellation) mm.tcl"} \
+	{"Millimeter elliptical" "main(constellation) mm.tcl"} \
 	{"NUONCE" "main(constellation) nuonce.tcl"} \
 	{"Odyssey" "main(constellation) odyssey.tcl"} \
 	{"Spaceway NGSO" "main(constellation) spaceway-ngso.tcl"} \
@@ -499,7 +505,7 @@ proc main(dblselect) {n} {
     edit(build)
 }
 
-proc main(shiftselect) {n} {
+proc main(itemselect) {n} {
     set s [.main.cmd.lb curselection]
 
     set found [lsearch -exact $s $n]
@@ -514,12 +520,12 @@ proc main(shiftselect) {n} {
 
 }
 
-proc main(shiftdblselect) {n} {
-    main(shiftselect) $n
+proc main(itemdblselect) {n} {
+    main(itemselect) $n
     edit(build)
 }
 
-proc main(controlselect) {n} {
+proc main(rangeselect) {n} {
     global sun_flag
 
     set s [.main.cmd.lb curselection]
@@ -560,8 +566,8 @@ proc main(controlselect) {n} {
     main(update_selection) [expr $n + (1 - $sun_flag)]
 }
 
-proc main(controldblselect) {n} {
-    main(controlselect) $n
+proc main(rangedblselect) {n} {
+    main(rangeselect) $n
     edit(build)
 }
 
